Tips | Unfuck Your Habitat

You're better than your mess.

## The UfYH Guide to Moving

So, you’re moving. Fun! No, wait. The opposite of that. Moving sucks, but there are things you can do to make it suck maybe a little less. If you can, start early. Don’t think, “Oh, my move is ages away. There’s nothing I can do this soon.” That is not good thinking. That is the kind of thinking that leaves you crying in the middle of your half-packed kitchen an...

Read More

## Things You Think Take Forever But Really Take Less Than a Minute

•putting the toilet paper or paper towel on the holder •washing a dish or putting it in the dishwasher instead of the sink •throwing trash in the trash can instead of leaving it on the counter •putting shoes back neatly instead of kicking them off wherever

Read More

## Why You Should Do the Stuff You’re Dreading First

I think it’s better to tackle the shit you really don’t want to do first for a number of reasons: •You’re most motivated when you start cleaning/doing a project. You have the most energy, and you’re in a mindset of Getting Shit Done. •If you do the easy stuff first, you run the risk of getting tired, feeling like you’ve done enough, and quitting before you get to the hard stuff. •Once the...

Read More

## Fruit Flies

OK, so every damn thing you find on the Internet will have you building some kind of contraption involving several of the following: wine, dish detergent, vinegar, plastic wrap, sugar, water, and a bowl or glass of some kind. None of these have ever worked for me. They may trap a few flies, but if there’s one thing that fruit flies are, it’s prolific. There are more of those fuckers than a...

Read More

## Random Laundry Tips

Facing the Big Rock Laundry Mountain? Do loads of like items. One load of all socks and underwear, and you’ll find that putting it away is a snap. One load of stuff that gets hung up. One load of stuff that goes in the middle dresser drawer. Save time in the crucial “put it away” step. Accidentally leave a load in the washer overnight? Put it through a rinse/spin cycle with a half-cup of...

Read More

## Once-Worn Clothing

(Clothes you’ve worn once and don’t consider “dirty” enough to wash, but you don’t want to put them back in your wardrobe’s general population.) Here’s my thing about once-worn clothing: if it’s clean enough to put back on your body, it’s clean enough to put back in your closet or drawers. If you’re really skeeved, but not skeeved enough to wash the stuff,...

Read More

## Rubbing Alcohol

Every time there’s a question involving a stain where my answer is “rubbing alcohol” (ballpoint pen, hair dye, etc.), someone always pipes in that you should use hairspray instead. Here’s the thing: hairspray works on stains because of the alcohol content in it. However, it also has a lot of added ingredients, like the polymers or gums that make it sticky, and fragrance, and sometimes...

Read More

## Denture Tablets

They can be used to clean: •Reusable water bottles •Stained coffee or tea cups •Stained toilet bowls •Flower vases with residue inside •Tomato sauce-stained Tupperware •Diamond jewelry

Read More

## Laundry and Dishes Have Three Steps

1. Wash 2. Dry 3. PUT IT AWAY, GODDAMMIT

Read More

## Let’s Talk About Habits For a Minute

SO MANY PEOPLE have done serious major unfucking lately, and IT’S AWESOME. I couldn’t be prouder. But once that initial high wears off, you need to focus on maintenance, or you’re going to end up right back where you started. I have a short list of things that, if you can make them habits, will prevent about 75% of the unfuckery that got you to the bad place to begin with. Bonus: most of these...

Read More

## Unfuck Tomorrow Morning

Wash the dishes in your sink Get your outfit for tomorrow together, including accessories Set up coffee/tea/breakfast Make your lunch Put your keys somewhere obvious Wash your face and brush your teeth Charge your electronics Pour a little cleaner in the toilet bowl (if you don’t have pets or children or sleepwalking adults) Set your alarm Go to bed at a reasonable hour...

Read More

## Unfuck Your Dishwasher

•To clean the inside surface of a dishwasher, use a mild dish soap solution with hot water (not too much soap; you don’t want bubbles later on), and use a sponge and an old toothbrush to get in all the corners, and the sides and bottom of the interior. Use your toothbrush or a toothpick to clear out the drain holes and water sprayers. Wipe down your surfaces with plain water when you’re done....

Read More

## UfYH Top Tens

Top ten cleaning products: Vinegar Baking soda Mr. Clean Magic Eraser Bar Keepers Friend Comet A steam mop Swiffer dry mop (you can replace the disposable cloths with a microfiber cloth) Scrub brushes Goo Gone Rubbing alcohol Top ten uses for vinegar: Drain volcano! (Pour baking soda down drain. Pour vinegar over it. Watch magic happen.) Add a cup to your laundry to get rid of musty odors and...

Read More